@@ -34,6 +34,7 @@ import subprocess
 import sys
 import tempfile
 import textwrap
+import traceback
 import zipfile
 from pathlib import Path
 from urllib.parse import urlparse
@@ -632,7 +633,7 @@ def download_file(url, local_filename=None):
 
 
 def get_properties_dict(string):
-    config = configparser.ConfigParser(delimiters=('='))
+    config = configparser.ConfigParser(delimiters=('='), strict=False)
     config.read_string('[DEFAULT]\n' + string)
     return dict(config.items('DEFAULT'))
 
@@ -724,8 +725,11 @@ def parse_ndk(url, d):
     revision = None
     if 'source.properties' in d:
         source_properties = get_properties_dict(d['source.properties'])
-        _add_to_revisions(url, source_properties)
-        revision = source_properties['pkg.revision']
+        revision = source_properties.get(
+            'pkg.baserevision', source_properties.get('pkg.revision')
+        )
+        if revision:
+            revisions[url] = tuple(LooseVersion(revision).version)
         for k in ('ndk', 'ndk-bundle'):
             key = (k, revision)
             if key not in packages:
@@ -881,8 +885,13 @@ def build_package_list(use_net=False):
     cached_checksums_signature = cachedir / (cached_checksums.name + '.asc')
     if cached_checksums.exists() and cached_checksums_signature.exists():
         verify(cached_checksums)
-        with cached_checksums.open() as fp:
-            _process_checksums(json.load(fp))
+        try:
+            with cached_checksums.open() as fp:
+                _process_checksums(json.load(fp))
+        except Exception:  # pylint: disable=broad-exception-caught
+            print(traceback.format_exc())
+            cached_checksums.unlink()
+            cached_checksums_signature.unlink()
     else:
         use_net = True  # need to fetch checksums.json, no cached version
 
